@@ -19,7 +19,7 @@ use base 'Exporter';
 
 our @EXPORT = 'testauto';
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 # ATTRIBUTES
 
@@ -463,10 +463,9 @@ scenario requires two blocks, i.e. C<scenario $name> and C<example $name>. The
 C<scenario> block should contain a description of the scenario and its purpose.
 The C<example> block must exist when documenting a method and should contain
 valid Perl code and return a value. The block may contain a "magic" comment in
-the form of C<given: synopsis> or C<given: example-$number $name> which if
-present will include the given code example(s) with the evaluation of the
-current block. Each scenario is tested and must be recognized to exist by the
-main package.
+the form of C<given: synopsis> or C<given: example $name> which if present will
+include the given code example(s) with the evaluation of the current block.
+Each scenario is tested and must be recognized to exist by the main package.
 
 =head2 attributes
 
@@ -689,7 +688,7 @@ testing exceptions simple, for example:
     $result;
   });
 
-Finally, The other manual testing hook (with some automation) is the C<example>
+Additionally, the other manual testing hook (with some automation) is the C<example>
 method. This hook evaluates (evals) a given example and returns the result as
 a L<Data::Object::Try> object.
 
@@ -701,6 +700,18 @@ a L<Data::Object::Try> object.
     $result;
   });
 
+Finally, the lesser used but super-useful manual testing hook is the
+C<scenario> method. This hook evaluates (evals) a given scenario code block and
+returns the result as a L<Data::Object::Try> object.
+
+  my $subtests = $test->subtests;
+
+  $subtests->scenario(-1, 'export-path-make', fun($tryable) {
+    ok my $result = $tryable->result, 'result ok';
+
+    $result;
+  });
+
 The test automation and document generation enabled through this framework
 makes it easy to maintain source/test/documentation parity. This also
 increases reusability and reduces the need for complicated state and test setup.
